RegisterFlags

Struct RegisterFlags 

pub struct RegisterFlags { /* private fields */ }
Flags describing register properties

Implementations

Source

impl RegisterFlags

pub const VIRTUAL: RegisterFlags

Default value if no flags set. Read/write pure virtual register that is not a stack pointer or flags

pub const PHYSICAL: RegisterFlags

Indicates that the register is a physical register

pub const LOCAL: RegisterFlags

Indicates that the register is a local temporary register of the current basic block

pub const FLAGS: RegisterFlags

Indicates that the register is used to hold CPU flags

pub const STACK_POINTER: RegisterFlags

Indicates that the register is used as the stack pointer

pub const IMAGE_BASE: RegisterFlags

Indicates that the register is an alias to the image base

pub const VOLATILE: RegisterFlags

Indicates that the register can change spontanously (e.g.: IA32_TIME_STAMP_COUNTER)

pub const READONLY: RegisterFlags

Indicates that the register can change spontanously (e.g.: IA32_TIME_STAMP_COUNTER)

pub const UNDEFINED: RegisterFlags

Indicates that it is the special “undefined” register

pub const INTERNAL: RegisterFlags

Indicates that it is a internal-use register that should be treated like any other virtual register

pub const SPECIAL: RegisterFlags

Combined mask of all special registers

pub const fn empty() -> RegisterFlags

Returns an empty set of flags

pub const fn all() -> RegisterFlags

Returns the set containing all flags.

pub const fn bits(&self) -> u64

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u64) -> Option<RegisterFlags>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u64) -> RegisterFlags

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u64) -> RegisterFlags

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: RegisterFlags) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: RegisterFlags) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: RegisterFlags)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: RegisterFlags)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: RegisterFlags)

Toggles the specified flags in-place.

pub fn set(&mut self, other: RegisterFlags, value: bool)

Inserts or removes the specified flags depending on the passed value.